@@ -1,5 +1,5 @@
 <?php
-/* $Id: romanian-utf-8.inc.php,v 2.67 2005/03/30 19:23:54 lem9 Exp $ */
+/* $Id: romanian-utf-8.inc.php,v 2.118.2.1 2006/02/17 12:43:00 lem9 Exp $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -85,7 +85,6 @@ $strBinaryLog = 'Binary log';
 $strBookmarkAllUsers = 'Permite tuturor utilizatorilor sa acceseze acest bookmark';
 $strBookmarkDeleted = 'Eticheta a fost stearsa.';
 $strBookmarkLabel = 'Eticheta - Label';
-$strBookmarkOptions = 'Optiuni bookmark';
 $strBookmarkQuery = 'Comanda SQL salvata (Bookmarked SQL-query)';
 $strBookmarkThis = 'Salveaza aceasta comanda SQL';
 $strBookmarkView = 'Numai vizualizare';
@@ -103,7 +102,6 @@ $strCantLoadRecodeIconv = 'Nu pot incarca extensia iconv sau recode necesar pent
 $strCantRenameIdxToPrimary = 'Nu poti redenumi index-ul la un nume PRIMARY!';
 $strCantUseRecodeIconv = 'Nu pot folosi functiile iconv nici libiconv nici recode_string in timp ce extensia este incarcata. Verifica configuratia PHP.';
 $strCardinality = 'Cardinalitate';
-$strCarriage = 'Enter: \\r';
 $strCaseInsensitive = 'caz-insenzitiv';
 $strCaseSensitive = 'caz-senzitiv';
 $strCentralEuropean = 'European de est';
@@ -216,7 +214,6 @@ $strDoYouReally = 'Sunteti sigur ca doriti sa ';
 $strDocu = 'Documentatie';
 $strDrop = 'Arunca';
 $strDropDatabaseStrongWarning = 'Sunteti pe cale sa DISTRUGETI o intreaga baza de date!';
-$strDropSelectedDatabases = 'Arunca baza(ele) de date selectata(e)';
 $strDropUsersDb = 'Arunca baza de date care are acelasi nume ca un utilizator.';
 $strDumpSaved = 'Copia a fost salvata in fisierul %s.';
 $strDumpXRows = 'Arunca %s randuri incepand de la randul %s.';
@@ -262,7 +259,6 @@ $strFieldsTerminatedBy = 'Campuri terminate de';
 $strFileAlreadyExists = 'Fisierul %s exista deja pe server, schimba denumirea fisierului sau bifeaza optiunea de suprascriere.';
 $strFileCouldNotBeRead = 'Fisierul nu poate fi citit';
 $strFileNameTemplate = 'Sablon nume fisier';
-$strFileNameTemplateHelp = 'Utilizati  __DB__ pentru denumirea bazei de date, __TABLE__  pentru denumirea tabelelor si optiuni %sany strftime%s pentru specifitii de timp, extensiile se vor adauga automat. Orice alt text va fi pastrat.';
 $strFileNameTemplateRemember = 'tine minte template';
 $strFixed = 'fixat';
 $strFlushPrivilegesNote = 'Nota: phpMyAdmin foloseste privilegiile utilizatorilor direct din tabela de privilegii din MySQL. Continutul acestei tabele poate diferi de cel original. In acest caz, reincarca de aici inainte de a continua %sreincarcarea drepturilor%s.';
@@ -299,13 +295,11 @@ $strHungarian = 'Unguresc';
 $strIcelandic = 'Islandic';
 $strId = 'ID';
 $strIdxFulltext = 'Tot textul';
-$strIfYouWish = 'In cazul in care doriti sa incarcati numai o parte a coloanelor tabelului, specificati o lista separata prin virgula.';
 $strIgnore = 'Ignora';
 $strIgnoreInserts = 'Utilizati ignorare inserari';
 $strIgnoringFile = 'Fisier %s ignorat';
 $strImportDocSQL = 'Import de fisiere docSQL';
 $strImportFiles = 'Import de fisiere';
-$strImportFinished = 'Importarea a fost finalizat';
 $strInUse = 'in folosinta';
 $strIndex = 'Index';
 $strIndexHasBeenDropped = 'Index %s a fost aruncat';
@@ -320,12 +314,9 @@ $strInnodbStat = 'InnoDB Status';
 $strInsecureMySQL = 'Configurarea ta contine setarile ce baza (utilizator root fara parola). Serverul MySQL poate fi astfel vulnerabil, neaparat sa repari aceasta greseala.';
 $strInsert = 'Inserare';
 $strInsertAsNewRow = 'Insereaza ca o noua linie';
-$strInsertBookmarkTitle = 'Va rugam introduceti titlul bookmark';
 $strInsertNewRow = 'Insereaza o noua linie';
-$strInsertTextfiles = 'Insereaza fisiere de text in tabel';
 $strInsertedRowId = 'ID rand inserat:';
 $strInsertedRows = 'Randuri inserate:';
-$strInstructions = 'Instructiuni';
 $strInternalNotNecessary = '* Nu se cere o relatie interna in cazul in care exista si in InnoDB.';
 $strInternalRelations = 'Relatii interne';
 
@@ -352,13 +343,10 @@ $strLatexStructure = 'Structura tabelului __TABLE__';
 $strLatvian = 'Leton';
 $strLengthSet = 'Lungime/Setare';
 $strLimitNumRows = 'Numarul de inregistrari de pe pagina';
-$strLineFeed = 'Dezvoltare linie: \\n';
 $strLinesTerminatedBy = 'Linii terminate de';
 $strLinkNotFound = 'Legatura invalida';
 $strLinksTo = 'Trimitere la';
 $strLithuanian = 'Lituanian';
-$strLoadExplanation = 'Metoda cea mai buna este cea implicit selectata, dar se poate schimba.';
-$strLoadMethod = 'methoda LOAD';
 $strLocalhost = 'Local';
 $strLocationTextfile = 'Locatia fisierului text';
 $strLogPassword = 'Parola:';
@@ -386,12 +374,10 @@ $strMbOverloadWarning = 'Ati activat mbstring.func_overload in configuratia PHP.
 $strModifications = 'Modificarile au fost salvate';
 $strModify = 'Modificare';
 $strModifyIndexTopic = 'Modifica un index';
-$strMoreStatusVars = 'Alte variabile de stare';
 $strMoveTable = 'Muta tabela la (database<b>.</b>table):';
 $strMoveTableOK = 'Tabela %s a fost mutat la %s.';
 $strMoveTableSameNames = 'Nu se poate copia tabelul pe cel existent pentru ca este acelasi!';
 $strMultilingual = 'Poliglot';
-$strMustSelectFile = 'Trebuie sa selectezi fisierul care urmeaza sa fie inserat.';
 $strMyISAMDataPointerSize = 'Marime data pointer';
 $strMyISAMDataPointerSizeDesc = 'Marimea pointer default in byti, care este folosit de CREATE TABLE pentru tabelele MyISAM atunci cand nu este specificat nici o optiune MAX_ROWS.';
 $strMyISAMMaxExtraSortFileSize = 'Marimea maxima pentru fisierele temporare la crearea indexului';
@@ -405,15 +391,12 @@ $strMyISAMRepairThreadsDesc = 'Daca aceasta valoare este mai mare decat 1, index
 $strMyISAMSortBufferSize = 'Sortare marime buffer';
 $strMyISAMSortBufferSizeDesc = 'Bufferul alocat la sortarea indexurilor MyISAM in timpul unei operatiuni REPAIR TABLE sau la crearea indexurilor cu CREATE INDEX sau ALTER TABLE.';
 $strMySQLCharset = 'Setul de caractere MySQL';
-$strMySQLReloaded = 'MySQL reincarcat.';
 $strMySQLSaid = 'MySQL zice: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% ruland pe %pma_s2% ca %pma_s3%';
 $strMySQLShowProcess = 'Afiseaza procesele';
 $strMySQLShowStatus = 'Afiseaza informatiile runtime MySQL';
 $strMySQLShowVars = 'Afiseaza variabilele de sistem MySQL';
 
 $strName = 'Nume';
-$strNeedPrimaryKey = 'Ar trebui sa definiti un primary key pentru acest tabel.';
 $strNext = 'Urmatorul';
 $strNo = 'Nu';
 $strNoActivity = 'Nu ati avut activitate de mai mult de %s seconde, va rugam sa va autentificati din nou';
@@ -432,7 +415,6 @@ $strNoPassword = 'Nu exista parola';
 $strNoPermission = 'Serverul web nu poate salva fisierul %s.';
 $strNoPhp = 'fara cod PHP';
 $strNoPrivileges = 'Nu exista drepturi de acces';
-$strNoQuery = 'Nu exista cerere SQL!';
 $strNoRights = 'Nu detineti drepturi de acces pentru a va afla aici!';
 $strNoRowsSelected = 'Nu e nici un rand selectat';
 $strNoSpace = 'Spatiu insuficient pentru salvarea fisierului %s.';
@@ -444,19 +426,15 @@ $strNone = 'Nici unul(a)';
 $strNotNumber = 'Acesta nu este un numar!';
 $strNotOK = 'Nu este bine';
 $strNotSet = '<b>%s</b> tabela nu a fost gasita sau nu este setat in %s';
-$strNotValidNumber = 'Nu este un numar valid de linie!';
 $strNull = 'Nul';
 $strNumSearchResultsInTable = '%s rezultat(e) in interiorul tabelei <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> rezultat(e)';
 $strNumTables = 'Tabele';
 
 $strOK = 'E bine';
-$strOftenQuotation = 'Adesea ghilimele. OPTIONAL inseamna ca numai campurile char si varchar sunt incluse intre caracterele "incadrat intre".';
 $strOperations = 'Operatii';
 $strOperator = 'Operator';
 $strOptimizeTable = 'Optimizare tabel';
-$strOptionalControls = 'Optional. Controleaza modul in care se citeste sau se scrie un caracter special.';
-$strOptionally = 'OPTIONAL';
 $strOr = 'Sau';
 $strOverhead = 'Asupra';
 $strOverwriteExisting = 'Suprascrie fisier(e) existent(e)';
@@ -547,7 +525,6 @@ $strRelationView = 'Vizualizare relationala';
 $strRelationalSchema = 'Schema relationala';
 $strRelations = 'Legaturi';
 $strRelationsForTable = 'RELATII PENTRU TABEL';
-$strReloadFailed = 'Reincarcare MySQL nereusita.';
 $strReloadMySQL = 'Reincarcare MySQL';
 $strReloadingThePrivileges = 'Reincarcarea drepturilor';
 $strRemoveSelectedUsers = 'Eliminarea utilizatorilor selectati';
@@ -555,7 +532,6 @@ $strRenameDatabaseOK = 'Baza de date %s a fost redenumita in %s';
 $strRenameTable = 'Rename tabel la';
 $strRenameTableOK = 'Tabelului %s i s-a dat un numele de %s';
 $strRepairTable = 'Reparare tabel';
-$strReplace = 'Inlocuire';
 $strReplaceNULLBy = 'Inlocuire NULL cu';
 $strReplaceTable = 'Inlocuieste datele tabelului cu fisier';
 $strReset = 'Resetare';
@@ -585,7 +561,7 @@ $strSQLExportType = 'Modul de export';
 $strSQLOptions = 'Optiuni SQL';
 $strSQLParserBugMessage = 'Exista o posibilitate de a fi gasit un BUG in parserul SQL. Verifica atent inca o data comanda si verifica daca semnele specifice sunt corecte. O alta posibilitate ar putea fi punerea unui fisier binar in afara zonei de text. Poti incerca aceasta comanda si printr-o linie de comanda MySQL. Eroarea MySQL de mai jos, daca e vreuna, poate sa te ajute la diagnosticarea problemei. Daca in continuare ai probleme cu executarea comenzii, redu o parte din comanda la aceea parte care cauzeaza problema si raporteaza acesta ca un BUG in sectiunea DE TAIAT';
 $strSQLParserUserError = 'Pare sa fie o eroare in comanda SQL. Eroarea MySQL de mai jos, daca e vreuna, poate sa te ajute la diagnosticarea problemei';
-$strSQLQuery = 'Comansa SQL';
+$strSQLQuery = 'Comanda SQL';
 $strSQLResult = 'Rezultat SQL';
 $strSQPBugInvalidIdentifer = 'Identificator invalid';
 $strSQPBugUnclosedQuote = 'Citare neinchisa';
@@ -683,9 +659,6 @@ $strTakeIt = 'alege';
 $strTblPrivileges = 'Drepturi specifice de tabele';
 $strTextAreaLength = ' Datorita lungimii sale, <br /> acest camp s-ar putea sa nu fie editabil';
 $strThai = 'Tailandez';
-$strTheContent = 'Continutul fisierului dumneavoastra a fost inserat.';
-$strTheContents = 'Continutul acestui fisier inlocuieste continutul tabelului selectat pentru liniile cu cheie primara identica.';
-$strTheTerminator = 'Terminatorul campurilor.';
 $strTheme = 'Sablon / Stil';
 $strThisHost = 'Acest Host';
 $strThisNotDirectory = 'Acesta nu este un director';
@@ -801,4 +774,209 @@ $strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cac
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
 $strInnoDBPages = 'pages';  //to translate
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
+$strPrivDescCreateView = 'Allows creating new views.';  //to translate
+$strPrivDescCreateUser = 'Allows creating, dropping and renaming user accounts.';  //to translate
+$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
+$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
+$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
+$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
+$strGeneratePassword = 'Generate Password';  //to translate
+$strGenerate = 'Generate';  //to translate
+$strCopy = 'Copy';  //to translate
+$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
+$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
+$strInvalidRowNumber = '%d is not valid row number.';  //to translate
+$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
+$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
+$strAndThen = 'and then';  //to translate
+$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
+$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
+$strCSV = 'CSV';  //to translate
+$strImport = 'Import';  //to translate
+$strImportFormat = 'Format of imported file';  //to translate
+$strFileToImport = 'File to import';  //to translate
+$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
+$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
+$strCSVImportOptions = 'CSV options';  //to translate
+$strPartialImport = 'Partial import';  //to translate
+$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
+$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
+$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
+$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
+$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
+$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
+$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
+$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
+$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
+$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
+$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
+$strFlushQueryCache = 'Flush query cache';  //to translate
+$strFlushTables = 'Flush (close) all tables';  //to translate
+$strHandler = 'Handler';  //to translate
+$strJoins = 'Joins';  //to translate
+$strKeyCache = 'Key cache';  //to translate
+$strMaxConnects = 'max. concurrent connections';  //to translate
+$strQueryCache = 'Query cache';  //to translate
+$strReplication = 'Replication';  //to translate
+$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
+$strShowOpenTables = 'Show open tables';  //to translate
+$strShowSlaveHosts = 'Show slave hosts';  //to translate
+$strShowSlaveStatus = 'Show slave status';  //to translate
+$strShowStatusReset = 'Reset';  //to translate
+$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
+$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
+$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
+$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
+$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
+$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
+$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
+$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
+$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
+$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
+$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
+$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
+$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
+$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
+$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
+$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
+$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
+$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
+$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
+$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
+$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
+$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
+$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
+$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
+$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
+$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
+$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
+$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
+$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
+$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
+$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
+$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
+$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
+$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
+$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
+$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
+$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
+$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
+$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
+$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
+$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
+$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
+$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
+$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
+$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
+$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
+$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
+$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
+$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
+$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
+$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
+$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
+$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
+$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
+$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
+$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
+$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
+$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
+$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
+$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
+$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
+$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
+$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
+$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
+$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
+$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
+$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
+$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
+$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
+$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
+$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
+$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
+$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
+$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
+$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
+$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
+$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
+$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
+$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
+$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
+$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
+$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
+$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
+$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
+$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
+$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
+$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
+$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
+$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
+$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
+$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
+$strSorting = 'Sorting';  //to translate
+$strTempData = 'Temporary data';  //to translate
+$strThreads = 'Threads';  //to translate
+$strLDI = 'CSV using LOAD DATA';  //to translate
+$strLDILocal = 'Use LOCAL keyword';  //to translate
+$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
+$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
+$strTableAlreadyExists = 'Table %s already exists!';  //to translate
+$strTransactionCoordinator = 'Transaction coordinator';  //to translate
+$strNumberOfFields = 'Number of fields';  //to translate
+$strShowingBookmark = 'Showing bookmark';  //to translate
+$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
+$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
+$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
+$strMaximalQueryLength = 'Maximal length of created query';  //to translate
+$strBookmarkCreated = 'Bookmark %s created';  //to translate
+$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
+$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
+$strEsperanto = 'Esperanto';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
 ?>
